Enum notify::Error
[−]
[src]
pub enum Error {
Generic(String),
Io(Error),
PathNotFound,
WatchNotFound,
}Errors generated from the notify crate
Variants
Generic(String)Generic error
May be used in cases where a platform specific error is mapped to this type
Io(Error)I/O errors
PathNotFoundThe provided path does not exist
WatchNotFoundAttempted to remove a watch that does not exist