Enum notify::RecursiveMode
[−]
[src]
pub enum RecursiveMode {
Recursive,
NonRecursive,
}Indicates whether only the provided directory or its sub-directories as well should be watched
Variants
RecursiveWatch all sub-directories as well, including directories created after installing the watch
NonRecursiveWatch only the provided directory